@@ -1,31 +1,36 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
 
-import sphinx_rtd_theme
-
-from ietfparse import __version__, version_info
+import ietfparse
 
 
 project = 'ietfparse'
-copyright = '2014, Dave Shawley'
-version = __version__
-release = '.'.join(str(x) for x in version_info[:2])
+copyright = '2014-2020, Dave Shawley'
+version = ietfparse.version
+release = '.'.join(str(x) for x in ietfparse.version_info[:2])
 
 needs_sphinx = '1.0'
 extensions = [
     'sphinx.ext.autodoc',
     'sphinx.ext.intersphinx',
     'sphinx.ext.viewcode',
+    'sphinxcontrib.httpdomain',
 ]
 templates_path = []
 source_suffix = '.rst'
 source_encoding = 'utf-8-sig'
 master_doc = 'index'
 pygments_style = 'sphinx'
-html_theme = 'sphinx_rtd_theme'
-html_theme_path = [sphinx_rtd_theme.get_html_theme_path()]
-html_static_path = []
+html_static_path = ['.']
 exclude_patterns = []
+html_sidebars = {
+    '**': ['about.html', 'navigation.html', 'searchbox.html'],
+}
+html_theme_options = {
+    'github_user': 'dave-shawley',
+    'github_repo': 'ietfparse',
+    'github_banner': True,
+}
 
 intersphinx_mapping = {
     'python': ('http://docs.python.org/3/', None),
